@@ -11,7 +11,9 @@ from ._errors import DbusClientMissingInterfaceError
 from ._errors import DbusClientMissingPropertyError
 from ._errors import DbusClientMissingSearchPropertiesError
 from ._errors import DbusClientRuntimeError
+from ._errors import DbusClientSearchConditionError
 from ._errors import DbusClientUnknownSearchPropertiesError
+from ._errors import DbusClientUniqueResultError
 
 from ._managed_objects import managed_object_class
 from ._managed_objects_queries import mo_query_builder
